==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/ServerWorkflowDetailsOnUploadArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property executionRole Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
 * @property workflowId A unique identifier for the workflow.
 */
public data class ServerWorkflowDetailsOnUploadArgs(
    public val executionRole: Output<String>,
    public val workflowId: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs =
        com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs.builder()
            .executionRole(executionRole.applyValue({ args0 -> args0 }))
            .workflowId(workflowId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServerWorkflowDetailsOnUploadArgs].
 */
@PulumiTagMarker
public class ServerWorkflowDetailsOnUploadArgsBuilder internal constructor() {
    private var executionRole: Output<String>? = null

    private var workflowId: Output<String>? = null

    /**
     * @param value Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
     */
    @JvmName("vbiqoogpvoifkhel")
    public suspend fun executionRole(`value`: Output<String>) {
        this.executionRole = value
    }

    /**
     * @param value A unique identifier for the workflow.
     */
    @JvmName("fhsdyboailhhudqc")
    public suspend fun workflowId(`value`: Output<String>) {
        this.workflowId = value
    }

    /**
     * @param value Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
     */
    @JvmName("wvkwdvujiicevcww")
    public suspend fun executionRole(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.executionRole = mapped
    }

    /**
     * @param value A unique identifier for the workflow.
     */
    @JvmName("ymdxqhjaebyytoke")
    public suspend fun workflowId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workflowId = mapped
    }

    internal fun build(): ServerWorkflowDetailsOnUploadArgs = ServerWorkflowDetailsOnUploadArgs(
        executionRole = executionRole ?: throw PulumiNullFieldException("executionRole"),
        workflowId = workflowId ?: throw PulumiNullFieldException("workflowId"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/ServerWorkflowDetailsOnUploadArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property executionRole Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
 * @property workflowId A unique identifier for the workflow.
 */
public data class ServerWorkflowDetailsOnUploadArgs(
    public val executionRole: Output<String>,
    public val workflowId: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs =
        com.pulumi.aws.transfer.inputs.ServerWorkflowDetailsOnUploadArgs.builder()
            .executionRole(executionRole.applyValue({ args0 -> args0 }))
            .workflowId(workflowId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServerWorkflowDetailsOnUploadArgs].
 */
@PulumiTagMarker
public class ServerWorkflowDetailsOnUploadArgsBuilder internal constructor() {
    private var executionRole: Output<String>? = null

    private var workflowId: Output<String>? = null

    /**
     * @param value Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
     */
    @JvmName("bedgabuvnxkqttdw")
    public suspend fun executionRole(`value`: Output<String>) {
        this.executionRole = value
    }

    /**
     * @param value A unique identifier for the workflow.
     */
    @JvmName("bbubsobnuypcnhnh")
    public suspend fun workflowId(`value`: Output<String>) {
        this.workflowId = value
    }

    /**
     * @param value Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources.
     */
    @JvmName("ibjlfdbbjjchsoor")
    public suspend fun executionRole(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.executionRole = mapped
    }

    /**
     * @param value A unique identifier for the workflow.
     */
    @JvmName("nfsepnckejfenvis")
    public suspend fun workflowId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workflowId = mapped
    }

    internal fun build(): ServerWorkflowDetailsOnUploadArgs = ServerWorkflowDetailsOnUploadArgs(
        executionRole = executionRole ?: throw PulumiNullFieldException("executionRole"),
        workflowId = workflowId ?: throw PulumiNullFieldException("workflowId"),
    )
}
